@@ -11,10 +11,12 @@ SHAPES TO ADD:
 '''
 
 class BaseCanvas(object):
-	def __init__(self, x=1200, y=800):
+	def __init__(self, x=1200, y=800, units=None):
 		self.width = x
 		self.height = y
 
+		self.units=units
+
 		self.background_color= None
 
 		self.draw_queue = []
@@ -25,6 +27,8 @@ class BaseCanvas(object):
 	def frame_index(self):
 		return self._frame_index
 
+
+
 	def draw(self):
 
 		for d in self.draw_queue:
@@ -37,6 +41,10 @@ class BaseCanvas(object):
 		# it was much easier to just hardcode it.
 		svg_canvas.viewBox = (0, 0, self.width, self.height)
 
+		if self.units:
+			svg_canvas.width = f'{self.width}{self.units}'
+			svg_canvas.height = f'{self.height}{self.units}'
+
 		if self.background_color:
 			svg_canvas.append(
 				drawSvg.Rectangle(x=0, y=0, width='100%', height='100%', fill=self.background_color)
